# Django Kakebo

A simple site made with django and exploiting the kakebo method.


[IT]
Il Kakebo (giapponese: 家計簿) è un metodo di risparmio e di gestione finanziaria della famiglia nato e sviluppato in Giappone da Motoko Hani (nel 1904).

Letteralmente può essere tradotto come "registro di casa". Vi sono variazioni della struttura, ma l'idea di base è la stessa.
All'inizio del mese, il kakeibo annota le entrate e le spese necessarie per il mese iniziale e decide una sorta di obiettivo di risparmio.

L'utente registra poi le proprie spese su base giornaliera, che vengono sommate alla fine della settimana e alla fine del mese.

Un riepilogo delle spese del mese viene scritto in kakeibo alla fine del mese.

Oltre alle spese e alle entrate, nel kakeibo si scrivono anche: pensieri e osservazioni, con l'obiettivo di aumentare la consapevolezza dei propri consumi.

In questo progetto viene elaborato un sito attraverso django che riporta lo stesso spirito del kakeibo tradizionale, dando all'utente un interfaccia pulita e utilizzabile da subito, con la semplice installazione del pacchetto/app

[EN]
The Kakebo (Japanese: 家計簿) is a method of household savings and financial management originated and developed in Japan by Motoko Hani (in 1904).

Literally it can be translated as "household ledger." There are variations in the structure, but the basic idea is the same.
At the beginning of the month, the kakeibo notes the income and expenses needed for the initial month and decides on a kind of savings goal.

The user then records his or her expenses on a daily basis, which are added up at the end of the week and at the end of the month.

A summary of the month's expenses is written in kakeibo at the end of the month.

In addition to expenses and income, also written in kakeibo are: thoughts and observations, with the goal of increasing awareness of one's consumption.

In this project, a site is developed through django that brings back the same spirit as traditional kakeibo, giving the user a clean and usable interface right out of the box, with the simple installation of the package/app
